@@ -10,13 +10,12 @@ app = Flask(__name__)
 
 
 def sachima_rpc_reports(req, local=True):
-    if local is not True:
-        with ClusterRpcProxy(CONFIG) as rpc:
-            res = rpc.data.get_report(req.json)
-    else:
-        d = Data()
-        res = d.get_report(req.json)
+    print("*"*80)
+    print(req.json)
+    d = Data()
+    res = d.get_report(req.json)
 
+    # TODO: is Waffle call me twice? improve it
     if req.json.get("dataonly") == "True":
         return {
             "dataSource": res.get("dataSource", []),
@@ -28,6 +27,6 @@ def sachima_rpc_reports(req, local=True):
 
 @app.route("/reports", methods=["POST"])
 def sachima():
-    print(request.json)
+    # print(request.json)
     return jsonify(sachima_rpc_reports(request))
 
